#
# This file osc-oracle-sample.spec is Sample Code and is licensed under the 
# following terms and conditions:
#
# Copyright (C) 2008, 2010 Oracle and/or its affiliates. All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1.  Redistributions of source code must retain the above copyright notice 
#     this list of conditions and the following disclaimer.
#
# 2.  The end-user documentation included with the redistribution, if any, 
#     must include the following acknowledgment: 
#
# "This product includes software developed by Oracle."
#
# Alternately, this acknowledgment may appear in the software itself, if 
# and wherever such third-party acknowledgments normally appear.
#
# 3.  The name "Oracle" may not be used to endorse or promote products
#     derived from this software.
#
# 4.  Products derived from this software may not be called "Oracle" nor 
#     may "Oracle" or "Ora" appear in their names.
#
# 5.  THIS SOFTWARE IS PROVIDED AS IS AND ANY EXPRESSED OR IMPLIED
#     WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#     IN NO EVENT SHALL ORACLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
#     INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
#     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
#     SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
#     HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
#     STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
#     IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
#     POSSIBILITY OF SUCH DAMAGE.
#

#
# Oracle Storage Connect plugin sample .spec file
#

#############################################################################
#                                                                           #
# These defines need to be set to reflect the specific plugin               #
#                                                                           #
#############################################################################

%define     vendor_name         vendor
%define     plugin_module       sample
%define     plugin_version      1.0.0
%define     plugin_release      4
%define     plugin_description  Oracle Storage Connect Sample plugin rpm.
%define     plugin_requires     None

Vendor:     Vendor Name
Summary:    Oracle Storage Connect Sample Plugin
URL:        http://vendor.com/

License:    GPLv2 / Whichever license the plugin should be released under
BuildArch:  noarch

#############################################################################
#                                                                           #
# If the plug-in is a split implementation (because some dependency)        #
# set split_plugin to 'yes' and split_requires to any RPM dependencies.     #
#                                                                           #
# Note: When split_plugin is set, two RPMs will be generated, the normal    #
#       osc-vendor-plugin-... one as well as the Meta package named         #
#       osc-requirer-vendor-plugin-...                                      #
#                                                                           #
#############################################################################

%define     split_plugin        no
%define     split_requires      None

#############################################################################
#                                                                           #
#  The following defines are generic and should not need to be changed      #
#                                                                           #
#############################################################################

%define     dist                .el5
%define     build_dir           %{_builddir}/%{name}-%{version}
%define     plugin_dir          /opt/storage-connect/plugins
%define     vendor_dir          %{plugin_dir}/%{vendor_name}
%define     install_dir         %{vendor_dir}/%{plugin_module}

Name:       osc-%{vendor_name}-%{plugin_module}
Version:    %{plugin_version}
Release:    %{plugin_release}%{dist}
Group:      Storage/StorageConnect
Source0:    %{name}-%{version}.tar.bz2
BuildRoot:  %{_tmppath}/%{name}-%{version}
Requires:   osc-plugin-manager >= 1.2.0

%if  %(test X%{plugin_requires} != XNone && echo 1 || echo 0)

Requires:   %{plugin_requires}

%endif


%if %(test X%{split_plugin} == Xyes && echo 1 || echo 0)

%package -n osc-requirer-%{vendor_name}-%{plugin_module}
Vendor:     %{vendor}
Summary:    Meta package for %{name}
URL:        %{url}
License:    %{license}

Version:    %{plugin_version}
Release:    %{plugin_release}%{dist}
Group:      %{group}
Requires:   %{name} = %{plugin_version}-%{plugin_release}
Requires:   %{split_requires}

%description -n osc-requirer-%{vendor_name}-%{plugin_module}
Requirer package for %{name}

%files -n osc-requirer-%{vendor_name}-%{plugin_module}
%defattr(0755, root, root)

%endif

%description
%{plugin_description}

%prep
%setup -q

%build

%install
rm -fr %{buildroot}
install -d -m0755 %{buildroot}/%{install_dir}
mv %{build_dir}/* %{buildroot}/%{install_dir}/.

%clean
rm -fr %{buildroot}

%files
%defattr(0755, root, root, 0755)
%attr(0755, root, root) /*

%preun
if [ $1 -eq 0 ]
then
    OSC_BIN=/opt/storage-connect/bin
    if [ -x "$OSC_BIN/announce_erase" ]
    then
        $OSC_BIN/announce_erase "%{name}" \
                                "%{version}-%{release}" \
                                "%{install_dir}" \
                                "%{vendor_name}" \
                                "%{plugin_module}"
    fi
    if [ -f %{vendor_dir}/__init__.py ]
    then
        python %{vendor_dir}/__init__.py %{vendor_dir} >/dev/null 2>&1
        if [ "$?" -eq 0 ]
        then
            rm -f %{vendor_dir}/__init__.py
            rm -f %{vendor_dir}/__init__.pyc
            rm -f %{vendor_dir}/__init__.pyo
        fi
    fi
fi
exit 0

%postun
if [ $1 -ge 1 ]
then
    OSC_BIN=/opt/storage-connect/bin
    if [ -x "$OSC_BIN/announce_upgrade" ]
    then
        $OSC_BIN/announce_upgrade "%{name}" \
                                  "%{version}-%{release}" \
                                  "%{install_dir}" \
                                  "%{vendor_name}" \
                                  "%{plugin_module}"
     fi
elif [ $1 -eq 0 ]
then
    rmdir --ignore-fail-on-non-empty %{install_dir} 2>/dev/null
    rmdir --ignore-fail-on-non-empty %{vendor_dir} 2>/dev/null
fi
exit 0

%post
OSC_BIN=/opt/storage-connect/bin
if [ -x "$OSC_BIN/announce_install" ]
then
    $OSC_BIN/announce_install "%{name}" \
                              "%{version}-%{release}" \
                              "%{install_dir}" \
                              "%{vendor_name}" \
                              "%{plugin_module}"
fi
if [ ! -f %{vendor_dir}/__init__.py ]
then
    cat >%{vendor_dir}/__init__.py <<__EOF__
"""
@copyright: Copyright (C) 2008, 2010 Oracle and/or its affiliates. All rights reserved.

@license:   This program is free software; you can redistribute it and/or
            modify it under the terms of the GNU General Public
            License as published by the Free Software Foundation, version 2.

            This program is distributed in the hope that it will be useful,
            but WITHOUT ANY WARRANTY; without even the implied warranty of
            MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
            General Public License for more details.

            You should have received a copy of the GNU General Public
            License along with this program; if not, write to the Free Software
            Foundation, Inc., 59 Temple Place - Suite 330, Boston,
            MA 021110-1307, USA

@summary:   This is just to enable the import of the plugins.
"""

#
# This is a major hack to get around RPM's limitation of not being able
# to specify the same file for multiple RPM installs
#
# Exit codes:
#   0 : No more dependencies
#   1 : ERROR condition
#   2 : Still have dependencies
#
if __name__ == '__main__':
    import sys
    import os
    if len(sys.argv) <= 1:
        print "ERROR: No vendor dir given!"
        sys.exit(1)

    try:
       vendor_dirs = os.listdir(sys.argv[1])
       ref_count = 0
       for vendor_dir in vendor_dirs:
           vendor_path = os.path.join(sys.argv[1], vendor_dir)
           if os.path.isdir(vendor_path):
               ref_count += 1

    except Exception, e:
        print "ERROR:", e
        sys.exit(1)

    if ref_count > 1:
        sys.exit(2)

    sys.exit(0)

__EOF__
fi
exit 0

%changelog
* Thu Jul  1 2010 Wiekus Beukes <wiekus.beukes@oracle.com> 1.0.0-4
- Added requirer RPM generation
- Updated the license

* Fri Jun  4 2010 Wiekus Beukes <wiekus.beukes@oracle.com> 1.0.0-3
- Fixed bug in the generated __init__.py

* Wed Mar  3 2010 Wiekus Beukes <wiekus.beukes@oracle.com> 1.0.0-2
- Removed ISA/IFS layer
- Added the vendor directory __init__.py logic

* Mon Nov 16 2009 Wiekus Beukes <wiekus.beukes@oracle.com> 1.0.0-1
- Initial packaging