#!/usr/bin/python
"""
@copyright: Copyright (C) 2010 Oracle and/or its affiliates. All rights reserved.

@license:   See the file COPYING for redistribution information.

@summary:   Test the cache in OSCPluginUtils.py
"""

import unittest
import sys
import time

from OSCCache import OSCDefaultCache


class CacheFixture(unittest.TestCase):
    def setUp(self):
        self._cache = OSCDefaultCache()

    def tearDown(self):
        del self._cache


class Test01Create(unittest.TestCase):
    def test_01_create(self):
        try:
            cache = OSCDefaultCache()
        except Exception, e:
            self.fail('Unable to create a cache: %s' % str(e))

class Test02GetSet(CacheFixture):
    def test_01_set(self):
        try:
            self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                            'testkey', 'testvalue')
        except Exception, e:
            self.fail('Unable to set a key: %s' % str(e))

    def test_02_get(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue')
        try:
            value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                    'testkey')
        except Exception, e:
            self.fail('Unable to get a key: %s' % str(e))
        self.assertEqual(value, 'testvalue')

    def test_03_get_empty(self):
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, None)


class Test03Expire(CacheFixture):
    def test_01_set_with_timeout(self):
        try:
            self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                            'testkey', 'testvalue', 1)
        except Exception, e:
            self.fail('Unable to set a key: %s' % str(e))

    def test_02_get_before_timeout(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue', 1)
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, 'testvalue')

    def test_03_get_after_timeout(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue', 1)
        time.sleep(1.1)
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, None)

    def test_04_extend(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue', 1)
        try:
            self._cache.extend('0f182240-4483-442b-bc88-90ec3e51ff77',
                               'testkey', 1)
        except Exception, e:
            self.fail('Unable to extend a key\'s timeout: %s' % str(e))

    def test_05_get_within_extend(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue', 1)
        time.sleep(0.1)
        self._cache.extend('0f182240-4483-442b-bc88-90ec3e51ff77',
                           'testkey', 1)
        time.sleep(1)
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, 'testvalue')

    def test_06_get_outside_extend(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue', 1)
        time.sleep(0.1)
        self._cache.extend('0f182240-4483-442b-bc88-90ec3e51ff77',
                           'testkey', 1)
        time.sleep(2)
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, None)


class Test04Clear(CacheFixture):
    def test_01_clear(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue')
        try:
            self._cache.clear('0f182240-4483-442b-bc88-90ec3e51ff77')
        except Exception, e:
            self.fail('Unable to clear cache: %s' % str(e))

    def test_02_get_after_clear(self):
        self._cache.set('0f182240-4483-442b-bc88-90ec3e51ff77',
                        'testkey', 'testvalue')
        self._cache.clear('0f182240-4483-442b-bc88-90ec3e51ff77')
        value = self._cache.get('0f182240-4483-442b-bc88-90ec3e51ff77',
                                'testkey')
        self.assertEqual(value, None)


if __name__ == '__main__':
    sys.exit(unittest.main(argv=sys.argv))
